.. HydrOffice BAG documentation master file, created by
   sphinx-quickstart on Sun Oct 18 16:44:37 2015.

HydrOffice BAG's documentation
==============================

Contents
--------

.. toctree::
   :maxdepth: 2

   in_brief
   license
   how_to_install
   how_to_use
   how_to_contribute
   how_to_release

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

